﻿using Hotline.Push;
using Hotline.Repository.SqlSugar.Extensions;
using Hotline.Share.Dtos;
using Hotline.Share.Dtos.Push;
using MapsterMapper;
using Microsoft.AspNetCore.Mvc;

namespace Hotline.Api.Controllers
{
    public class PushMessageController : BaseController
    {
        private readonly IMessageRepository _messageRepository;
        private readonly IMapper _mapper;
        private readonly IPushDomainService _pushDomainService;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="messageRepository"></param>
        /// <param name="mapper"></param>
        /// <param name="pushDomainService"></param>
        public PushMessageController(IMessageRepository messageRepository, IMapper mapper, IPushDomainService pushDomainService)
        {
            _messageRepository = messageRepository;
            _mapper = mapper;
            _pushDomainService = pushDomainService;
        }

        /// <summary>
        /// 新增
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpPut("add")]
        public async Task AddMessage([FromBody] MessageDto dto)
        {
            await _pushDomainService.PushAsync(dto, HttpContext.RequestAborted);
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="pagedDto"></param>
        /// <returns></returns>
        [HttpGet("getlist")]
        public async Task<PagedDto<MessageDataDto>> AllMessage([FromQuery] MessagePagedDto pagedDto)
        {
            var (total, items) = await _messageRepository
                    .Queryable()
                    .Includes(it => it.User)
                    .Includes(it => it.SystemOrganize)
                    .Includes(it => it.Order)
                    .WhereIF(pagedDto.PushBusiness.HasValue, d => d.PushBusiness == pagedDto.PushBusiness)
                    .WhereIF(pagedDto.Status.HasValue, d => d.Status == pagedDto.Status)
                    .WhereIF(!string.IsNullOrEmpty(pagedDto.Keyword), d => d.Name.Contains(pagedDto.Keyword!) || d.Content.Contains(pagedDto.Keyword!) || d.TelNumber.Contains(pagedDto.Keyword!) || d.User.Name.Contains(pagedDto.Keyword!) || d.SystemOrganize.OrgName.Contains(pagedDto.Keyword!))
                    .WhereIF(pagedDto.StartTime.HasValue, d => d.SendTime >= pagedDto.StartTime)
                    .WhereIF(pagedDto.EndTime.HasValue, d => d.SendTime <= pagedDto.EndTime)
                    .OrderByDescending(it => it.CreationTime)
                    .ToPagedListAsync(pagedDto.PageIndex, pagedDto.PageSize, HttpContext.RequestAborted);

            return new PagedDto<MessageDataDto>(total, _mapper.Map<IReadOnlyList<MessageDataDto>>(items));

        }
    }
}
