﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Hotline.Share.Enums.Order;
using Hotline.Share.Requests;

namespace Hotline.Share.Dtos.Order
{
    public record QueryOrderDto : PagedKeywordRequest
    {

        /// <summary>
        /// 诉求内容
        /// </summary>
        public string? Content { get; set; }

        /// <summary>
        /// 受理类型
        /// </summary>
        public List<EAcceptType> AcceptTypes { get; set; } = new();

        /// <summary>
        /// 来源渠道
        /// </summary>
        public List<EChannel> Channels { get; set; } = new();

        /// <summary>
        /// 转接号码（转接来源）
        /// </summary>
        public string? TransferPhone { get; set; }

        /// <summary>
        /// 热点分类
        /// </summary>
        public List<string> HotspotIds { get; set; } = new();

        /// <summary>
        /// 接办部门
        /// </summary>
        public List<string> OrgCodes { get; set; } = new();

        /// <summary>
        /// 受理坐席名字或工号
        /// </summary>
        public string? NameOrNo { get; set; }

        /// <summary>
        /// 受理时间(工单创建时间)
        /// </summary>
        public DateTime? CreationTimeStart { get; set; }
        public DateTime? CreationTimeEnd { get; set; }

        /// <summary>
        /// 紧急程度
        /// </summary>
        public List<EEmergencyLevel> EmergencyLevels { get; set; } = new();

        /// <summary>
        /// 来电或联系电话
        /// </summary>
        public string? PhoneNo { get; set; }

        /// <summary>
        /// 推送分类
        /// </summary>
        public string? PushTypeCode { get; set; }

        /// <summary>
        /// 过期时间
        /// </summary>
        public DateTime? ExpiredTimeStart { get; set; }
        public DateTime? ExpiredTimeEnd { get; set; }

        /// <summary>
        /// 工单状态
        /// </summary>
        public List<EOrderStatus> Statuses { get; set; } = new();
    }

    public record QueryOrderPublishDto : PagedRequest
    {
        /// <summary>
        /// 发布状态
        /// </summary>
        public EPubState PubState { get; set; }

        /// <summary>
        /// 工单标题
        /// </summary>
        public string OrderTitle { get; set; }

        /// <summary>
        /// 发布人
        /// </summary>
        public string PubMan { get; set; }

        /// <summary>
        /// 发布范围
        /// </summary>
        public EPublishState? PubRange { get; set; }

        /// <summary>
        /// 受理类型
        /// </summary>
        public List<EAcceptType> AcceptTypes { get; set; } = new();

        /// <summary>
        /// 热点分类
        /// </summary>
        public List<string> HotspotIds { get; set; } = new();

        /// <summary>
        /// 受理时间(工单创建时间)
        /// </summary>
        public DateTime? CreationTimeStart { get; set; }
        public DateTime? CreationTimeEnd { get; set; }

        /// <summary>
        /// 归档时间
        /// </summary>
        public DateTime? FiledTimeStart { get; set; }
        public DateTime? FiledTimeEnd { get; set; }

    }

    public enum EPubState
    {
        /// <summary>
        /// 全部
        /// </summary>
        [Description("全部")]
        All = 0,
        /// <summary>
        /// 已发布
        /// </summary>
        [Description("已发布")]
        Pub = 1,
        /// <summary>
        /// 未发布
        /// </summary>
        [Description("未发布")]
        NoPub = 2
    }

}
