﻿using Hotline.Orders;
using Hotline.Settings;
using Hotline.Share.Enums.Push;
using Hotline.Users;
using SqlSugar;
using XF.Domain.Repository;

namespace Hotline.Push
{
    /// <summary>
    /// 推送消息
    /// </summary>
    public class Message : CreationEntity
    {
        /// <summary>
        /// 消息推送业务
        /// </summary>
        public EPushBusiness PushBusiness { get; set; }

        /// <summary>
        /// 外部业务唯一编号
        /// </summary>
        public string ExternalId { get; set; }

        /// <summary>
        /// 推送平台
        /// </summary>
        public EPushPlatform PushPlatform { get; set; }

        /// <summary>
        /// 推送状态
        /// </summary>
        public EPushStatus Status { get; set; }

        /// <summary>
        /// 模板
        /// </summary>
        [SugarColumn(IsNullable = true)]
        public string? Template { get; set; }

        /// <summary>
        /// 内容
        /// </summary>
        public string Content { get; set; }

        /// <summary>
        /// 备注
        /// </summary>
        [SugarColumn(IsNullable = true)]
        public string? Remark { get; set; }

        /// <summary>
        /// 接收姓名
        /// </summary>
        public string Name { get; set; }

        /// <summary>
        /// 接收手机号码
        /// </summary>
        public string TelNumber { get; set; }

        /// <summary>
        /// 发送时间
        /// </summary>
        public DateTime? SendTime { get; set; }

        /// <summary>
        /// 关联工单编号
        /// </summary>
        [SugarColumn(IsNullable = true)]
        public string? OrderId { get; set; }

        /// <summary>
        /// 发送人
        /// </summary>
        [Navigate(NavigateType.OneToOne, nameof(CreatorId))]//
        public User User { get; set; }

        /// <summary>
        /// 发送部门
        /// </summary>
        [Navigate(NavigateType.OneToOne, nameof(CreatorOrgId))]//
        public SystemOrganize SystemOrganize { get; set; }

        /// <summary>
        /// 关联工单信息
        /// </summary>
        [Navigate(NavigateType.OneToOne, nameof(OrderId))]//
        public Order Order { get; set; }

        ///// <summary>
        ///// 参数
        ///// </summary>
        //[SqlSugar.SugarColumn(IsIgnore = true)]
        //public List<string> Params { get; set; }
    }
}
