﻿using Hotline.Share.Dtos.Push;
using MapsterMapper;
using System.Text.RegularExpressions;
using XF.Domain.Dependency;
using XF.Domain.Exceptions;

namespace Hotline.Push;

public class PushDomainService : IPushDomainService, IScopeDependency
{

    private readonly IMessageRepository _messageRepository;
    private readonly IMapper _mapper;

    /// <summary>
    /// 
    /// </summary>
    /// <param name="messageRepository"></param>
    /// <param name="mapper"></param>
    public PushDomainService(IMessageRepository messageRepository, IMapper mapper)
    {
        _messageRepository = messageRepository;
        _mapper = mapper;
    }

    /// <summary>
    /// 业务处理
    /// </summary>
    /// <param name="messageDto"></param>
    /// <param name="cancellation"></param>
    /// <returns></returns>
    public async Task PushAsync(MessageDto messageDto, CancellationToken cancellation)
    {
        if (messageDto == null)
        {
            throw UserFriendlyException.SameMessage("消息不能为空！");
        }

        //如果模板为空，参数为空则直接用短信内容
        if (!string.IsNullOrEmpty(messageDto.Template) && messageDto.Params.Count > 0)
        {
            string Template = messageDto.Template;
            //正则查询模板中需要替换的内容
            Regex regex = new(@"\{[a-zA-Z0-9]{1,}\}");
            var matches = regex.Matches(Template);
            if (matches != null && matches.Count != messageDto.Params.Count)
                //参数与需要替换的字符数不匹配
                //throw UserFriendlyException.SameMessage("模板需要参数与实际传递参数个数不匹配！");
                messageDto.Remark = "模板需要参数与实际传递参数个数不匹配！";

            //根据正则查询出来的匹配项替换内容
            for (int i = 0; i < matches.Count; i++)
                Template = Template.Replace(matches[i].ToString(), messageDto.Params[i]);

            messageDto.Content = Template;
        }
        var message = _mapper.Map<Message>(messageDto);
        //写入本地数据库
        var id = await _messageRepository.AddAsync(message);

        //调用短信发送业务
    }
}